import React, { Suspense, lazy, useState, useEffect } from 'react';
import { Route, Switch, withRouter, Redirect, } from 'react-router-dom';
import { useConfig, useAuth } from '@payloadcms/config-provider';
import List from './views/collections/List';
import DefaultTemplate from './templates/Default';
import { requests } from '../api';
import Loading from './elements/Loading';
import StayLoggedIn from './modals/StayLoggedIn';
import Unlicensed from './views/Unlicensed';
const Dashboard = lazy(() => import('./views/Dashboard'));
const ForgotPassword = lazy(() => import('./views/ForgotPassword'));
const Login = lazy(() => import('./views/Login'));
const Logout = lazy(() => import('./views/Logout'));
const NotFound = lazy(() => import('./views/NotFound'));
const Verify = lazy(() => import('./views/Verify'));
const CreateFirstUser = lazy(() => import('./views/CreateFirstUser'));
const Edit = lazy(() => import('./views/collections/Edit'));
const EditGlobal = lazy(() => import('./views/Global'));
const ResetPassword = lazy(() => import('./views/ResetPassword'));
const Unauthorized = lazy(() => import('./views/Unauthorized'));
const UnauthorizedUser = lazy(() => import('./views/UnauthorizedUser'));
const Account = lazy(() => import('./views/Account'));
const Routes = () => {
    const [initialized, setInitialized] = useState(null);
    const { user, permissions, permissions: { canAccessAdmin }, refreshCookie } = useAuth();
    const { admin: { user: userSlug }, routes, collections, globals, } = useConfig();
    useEffect(() => {
        requests.get(`${routes.api}/${userSlug}/init`).then((res) => res.json().then((data) => {
            if (data && 'initialized' in data) {
                setInitialized(data.initialized);
            }
        }));
    }, [routes, userSlug]);
    return (React.createElement(Suspense, { fallback: React.createElement(Loading, null) },
        React.createElement(Route, { path: routes.admin, render: ({ match }) => {
                if (initialized === false) {
                    return (React.createElement(Switch, null,
                        React.createElement(Route, { path: `${match.url}/create-first-user` },
                            React.createElement(CreateFirstUser, { setInitialized: setInitialized })),
                        React.createElement(Route, null,
                            React.createElement(Redirect, { to: `${match.url}/create-first-user` }))));
                }
                if (initialized === true) {
                    return (React.createElement(Switch, null,
                        React.createElement(Route, { path: `${match.url}/login` },
                            React.createElement(Login, null)),
                        React.createElement(Route, { path: `${match.url}/logout` },
                            React.createElement(Logout, null)),
                        React.createElement(Route, { path: `${match.url}/logout-inactivity` },
                            React.createElement(Logout, { inactivity: true })),
                        React.createElement(Route, { path: `${match.url}/forgot` },
                            React.createElement(ForgotPassword, null)),
                        React.createElement(Route, { path: `${match.url}/reset/:token` },
                            React.createElement(ResetPassword, null)),
                        React.createElement(Route, { path: `${match.url}/unlicensed-domain` },
                            React.createElement(Unlicensed, null)),
                        React.createElement(Route, { path: `${match.url}/unauthorized-user` },
                            React.createElement(UnauthorizedUser, null)),
                        collections.map((collection) => {
                            var _a;
                            if ((_a = collection === null || collection === void 0 ? void 0 : collection.auth) === null || _a === void 0 ? void 0 : _a.verify) {
                                return (React.createElement(Route, { key: `${collection.slug}-verify`, path: `${match.url}/${collection.slug}/verify/:token`, exact: true },
                                    React.createElement(Verify, { collection: collection })));
                            }
                            return null;
                        }),
                        React.createElement(Route, { render: () => {
                                if (user) {
                                    if (canAccessAdmin) {
                                        return (React.createElement(DefaultTemplate, null,
                                            React.createElement(Switch, null,
                                                React.createElement(Route, { path: `${match.url}/`, exact: true },
                                                    React.createElement(Dashboard, null)),
                                                React.createElement(Route, { path: `${match.url}/account` },
                                                    React.createElement(Account, null)),
                                                collections.map((collection) => (React.createElement(Route, { key: `${collection.slug}-list`, path: `${match.url}/collections/${collection.slug}`, exact: true, render: (routeProps) => {
                                                        var _a, _b, _c;
                                                        if ((_c = (_b = (_a = permissions === null || permissions === void 0 ? void 0 : permissions.collections) === null || _a === void 0 ? void 0 : _a[collection.slug]) === null || _b === void 0 ? void 0 : _b.read) === null || _c === void 0 ? void 0 : _c.permission) {
                                                            return (React.createElement(List, { ...routeProps, collection: collection }));
                                                        }
                                                        return React.createElement(Unauthorized, null);
                                                    } }))),
                                                collections.map((collection) => (React.createElement(Route, { key: `${collection.slug}-create`, path: `${match.url}/collections/${collection.slug}/create`, exact: true, render: (routeProps) => {
                                                        var _a, _b, _c;
                                                        if ((_c = (_b = (_a = permissions === null || permissions === void 0 ? void 0 : permissions.collections) === null || _a === void 0 ? void 0 : _a[collection.slug]) === null || _b === void 0 ? void 0 : _b.create) === null || _c === void 0 ? void 0 : _c.permission) {
                                                            return (React.createElement(Edit, { ...routeProps, collection: collection }));
                                                        }
                                                        return React.createElement(Unauthorized, null);
                                                    } }))),
                                                collections.map((collection) => (React.createElement(Route, { key: `${collection.slug}-edit`, path: `${match.url}/collections/${collection.slug}/:id`, exact: true, render: (routeProps) => {
                                                        var _a, _b, _c;
                                                        if ((_c = (_b = (_a = permissions === null || permissions === void 0 ? void 0 : permissions.collections) === null || _a === void 0 ? void 0 : _a[collection.slug]) === null || _b === void 0 ? void 0 : _b.read) === null || _c === void 0 ? void 0 : _c.permission) {
                                                            return (React.createElement(Edit, { isEditing: true, ...routeProps, collection: collection }));
                                                        }
                                                        return React.createElement(Unauthorized, null);
                                                    } }))),
                                                globals && globals.map((global) => (React.createElement(Route, { key: `${global.slug}`, path: `${match.url}/globals/${global.slug}`, exact: true, render: (routeProps) => {
                                                        var _a, _b, _c;
                                                        if ((_c = (_b = (_a = permissions === null || permissions === void 0 ? void 0 : permissions.globals) === null || _a === void 0 ? void 0 : _a[global.slug]) === null || _b === void 0 ? void 0 : _b.read) === null || _c === void 0 ? void 0 : _c.permission) {
                                                            return (React.createElement(EditGlobal, { ...routeProps, global: global }));
                                                        }
                                                        return React.createElement(Unauthorized, null);
                                                    } }))),
                                                React.createElement(Route, { path: `${match.url}*` },
                                                    React.createElement(NotFound, null)))));
                                    }
                                    if (canAccessAdmin === false) {
                                        return React.createElement(Unauthorized, null);
                                    }
                                    return React.createElement(Loading, null);
                                }
                                if (user === undefined) {
                                    return React.createElement(Loading, null);
                                }
                                return React.createElement(Redirect, { to: `${match.url}/login` });
                            } }),
                        React.createElement(Route, { path: `${match.url}*` },
                            React.createElement(NotFound, null))));
                }
                return null;
            } }),
        React.createElement(StayLoggedIn, { refreshCookie: refreshCookie })));
};
export default withRouter(Routes);
