import React, { useCallback } from 'react';
import DatePicker from '../../../elements/DatePicker';
import withCondition from '../../withCondition';
import useFieldType from '../../useFieldType';
import Label from '../../Label';
import Error from '../../Error';
import { date as dateValidation } from '../../../../../fields/validations';
import './index.scss';
const baseClass = 'date-time-field';
const DateTime = (props) => {
    const { path: pathFromProps, name, required, validate = dateValidation, label, admin: { placeholder, readOnly, style, width, date, condition, } = {}, } = props;
    const path = pathFromProps || name;
    const memoizedValidate = useCallback((value) => {
        const validationResult = validate(value, { required });
        return validationResult;
    }, [validate, required]);
    const { value, showError, errorMessage, setValue, } = useFieldType({
        path,
        validate: memoizedValidate,
        condition,
    });
    const classes = [
        'field-type',
        baseClass,
        showError && `${baseClass}--has-error`,
        readOnly && 'read-only',
    ].filter(Boolean).join(' ');
    return (React.createElement("div", { className: classes, style: {
            ...style,
            width,
        } },
        React.createElement(Error, { showError: showError, message: errorMessage }),
        React.createElement(Label, { htmlFor: path, label: label, required: required }),
        React.createElement("div", { className: `${baseClass}__input-wrapper` },
            React.createElement(DatePicker, { ...date, placeholder: placeholder, readOnly: readOnly, onChange: readOnly ? undefined : setValue, value: value }))));
};
export default withCondition(DateTime);
