import React, { useCallback } from 'react';
import useFieldType from '../../useFieldType';
import withCondition from '../../withCondition';
import Error from '../../Error';
import Label from '../../Label';
import RadioInput from './RadioInput';
import { radio } from '../../../../../fields/validations';
import { optionIsObject } from '../../../../../fields/config/types';
import './index.scss';
const baseClass = 'radio-group';
const RadioGroup = (props) => {
    const { name, path: pathFromProps, required, validate = radio, label, admin: { readOnly, layout = 'horizontal', style, width, condition, } = {}, options, } = props;
    const path = pathFromProps || name;
    const memoizedValidate = useCallback((value) => {
        const validationResult = validate(value, { required, options });
        return validationResult;
    }, [validate, required, options]);
    const { value, showError, errorMessage, setValue, } = useFieldType({
        path,
        validate: memoizedValidate,
        condition,
    });
    const classes = [
        'field-type',
        baseClass,
        `${baseClass}--layout-${layout}`,
        showError && 'error',
        readOnly && `${baseClass}--read-only`,
    ].filter(Boolean).join(' ');
    return (React.createElement("div", { className: classes, style: {
            ...style,
            width,
        } },
        React.createElement("div", { className: `${baseClass}__error-wrap` },
            React.createElement(Error, { showError: showError, message: errorMessage })),
        React.createElement(Label, { htmlFor: path, label: label, required: required }),
        React.createElement("ul", { className: `${baseClass}--group` }, options.map((option) => {
            let optionValue = '';
            if (optionIsObject(option)) {
                optionValue = option.value;
            }
            else {
                optionValue = option;
            }
            const isSelected = String(optionValue) === String(value);
            return (React.createElement("li", { key: `${path} - ${optionValue}` },
                React.createElement(RadioInput, { path: path, isSelected: isSelected, option: optionIsObject(option) ? option : { label: option, value: option }, onChange: readOnly ? undefined : setValue })));
        }))));
};
export default withCondition(RadioGroup);
