import React from 'react';
import useFieldType from '../../useFieldType';
import withCondition from '../../withCondition';
import Label from '../../Label';
import Error from '../../Error';
import { text } from '../../../../../fields/validations';
import './index.scss';
const Text = (props) => {
    const { path: pathFromProps, name, required, validate = text, label, admin: { placeholder, readOnly, style, width, condition, } = {}, } = props;
    const path = pathFromProps || name;
    const fieldType = useFieldType({
        path,
        validate,
        condition,
        enableDebouncedValue: true,
    });
    const { value, showError, setValue, errorMessage, } = fieldType;
    const classes = [
        'field-type',
        'text',
        showError && 'error',
        readOnly && 'read-only',
    ].filter(Boolean).join(' ');
    return (React.createElement("div", { className: classes, style: {
            ...style,
            width,
        } },
        React.createElement(Error, { showError: showError, message: errorMessage }),
        React.createElement(Label, { htmlFor: path, label: label, required: required }),
        React.createElement("input", { value: value || '', onChange: setValue, disabled: readOnly, placeholder: placeholder, type: "text", id: path, name: path })));
};
export default withCondition(Text);
