import React, { useCallback } from 'react';
import useFieldType from '../../useFieldType';
import withCondition from '../../withCondition';
import Label from '../../Label';
import Error from '../../Error';
import { textarea } from '../../../../../fields/validations';
import './index.scss';
const Textarea = (props) => {
    const { path: pathFromProps, name, required, validate = textarea, admin: { readOnly, style, width, placeholder, rows, condition, } = {}, label, minLength, maxLength, } = props;
    const path = pathFromProps || name;
    const memoizedValidate = useCallback((value) => {
        const validationResult = validate(value, { minLength, maxLength, required });
        return validationResult;
    }, [validate, maxLength, minLength, required]);
    const { value, showError, setValue, errorMessage, } = useFieldType({
        path,
        validate: memoizedValidate,
        enableDebouncedValue: true,
        condition,
    });
    const classes = [
        'field-type',
        'textarea',
        showError && 'error',
        readOnly && 'read-only',
    ].filter(Boolean).join(' ');
    return (React.createElement("div", { className: classes, style: {
            ...style,
            width,
        } },
        React.createElement(Error, { showError: showError, message: errorMessage }),
        React.createElement(Label, { htmlFor: path, label: label, required: required }),
        React.createElement("textarea", { value: value || '', onChange: setValue, disabled: readOnly, placeholder: placeholder, id: path, name: path, rows: rows })));
};
export default withCondition(Textarea);
