import React, { useEffect } from 'react';
import { useWatchForm } from '../Form/context';
const withCondition = (Field) => {
    const CheckForCondition = (props) => {
        const { admin: { condition, } = {}, } = props;
        if (condition) {
            return React.createElement(WithCondition, { ...props });
        }
        return React.createElement(Field, { ...props });
    };
    const WithCondition = (props) => {
        const { name, path: pathFromProps, admin: { condition, } = {}, } = props;
        const path = pathFromProps || name;
        const { getData, getSiblingData, getField, dispatchFields } = useWatchForm();
        const data = getData();
        const siblingData = getSiblingData(path);
        const passesCondition = condition ? condition(data, siblingData) : true;
        useEffect(() => {
            if (!passesCondition) {
                const field = getField(path);
                dispatchFields({
                    ...field,
                    path,
                    valid: true,
                });
            }
        }, [passesCondition, getField, dispatchFields, path]);
        if (passesCondition) {
            return React.createElement(Field, { ...props });
        }
        return null;
    };
    return CheckForCondition;
};
export default withCondition;
