import React from 'react';
import { Model, Document } from 'mongoose';
import { DeepRequired } from 'ts-essentials';
import { PayloadRequest } from '../../express/types';
import { Access, GeneratePreviewURL } from '../../config/types';
import { Field } from '../../fields/config/types';
export declare type BeforeValidateHook = (args?: {
    data?: any;
    req?: PayloadRequest;
    originalDoc?: any;
}) => any;
export declare type BeforeChangeHook = (args?: {
    data: any;
    req: PayloadRequest;
    originalDoc?: any;
}) => any;
export declare type AfterChangeHook = (args?: {
    doc: any;
    req: PayloadRequest;
}) => any;
export declare type BeforeReadHook = (args?: {
    doc: any;
    req: PayloadRequest;
    query: {
        [key: string]: any;
    };
}) => any;
export declare type AfterReadHook = (args?: {
    doc: any;
    req: PayloadRequest;
    query?: {
        [key: string]: any;
    };
}) => any;
export declare type GlobalModel = Model<Document>;
export declare type PayloadGlobalConfig = {
    slug: string;
    label?: string;
    preview?: GeneratePreviewURL;
    hooks?: {
        beforeValidate?: BeforeValidateHook[];
        beforeChange?: BeforeChangeHook[];
        afterChange?: AfterChangeHook[];
        beforeRead?: BeforeReadHook[];
        afterRead?: AfterReadHook[];
    };
    access?: {
        read?: Access;
        update?: Access;
        admin?: Access;
    };
    fields: Field[];
    admin?: {
        components?: {
            views?: {
                Edit?: React.ComponentType;
            };
        };
    };
};
export interface GlobalConfig extends Omit<DeepRequired<PayloadGlobalConfig>, 'fields'> {
    fields: Field[];
}
export declare type Globals = {
    Model: GlobalModel;
    config: GlobalConfig[];
};
